@@ -169,11 +169,11 @@ def port_callback(ctx: Context, param: Option, value: str | int) -> int | None:
         return int(value)
 
 
-def commands_callback(ctx: Context, _param: Option, incomplete: str) -> list[CompletionItem]:
+def commands_completion(ctx: Context, param: Option, incomplete: str) -> list[CompletionItem]:
     try:
         return [
             CompletionItem(n, help=c.short_help)
-            for n, c in reduce(lambda a, c: a.commands[c], ctx.params.get("commands", ctx.args), app).commands.items()
+            for n, c in reduce(lambda a, c: a.commands[c], ctx.params.get(param.name, ctx.args), app).commands.items()
             if n.lower().startswith(incomplete.lower())
         ]
     except (KeyError, AttributeError):
@@ -261,7 +261,7 @@ def app_updates(ctx: Context, shell: bool):
 
 @app.command("help", context_settings={"ignore_unknown_options": True})
 @argument("commands", nargs=-1, required=False, type=str, callback=lambda _c, _p, v: list(v),
-          shell_complete=commands_callback)
+          shell_complete=commands_completion)
 @color_option
 @help_option
 @option("--database", expose_value=False, required=False, hidden=True)
@@ -354,7 +354,7 @@ def app_server(ctx: Context, database: Callable[..., Database], host: str | None
 @docstring_format("\n    ".join(
     f"* {_pride_colors['pride'][(i % ((len(_pride_colors[f]) - 1) // 3)) * 3][supports_truecolor]}{f}{reset}"
     for i, f in enumerate(_pride_colors.keys())))
-def paw(ctx: Context, flag: str, true_color: bool):
+def paw(ctx: Context, flag: str, truecolor: bool):
     """
     Print a PRIDE {yellow}FLAG{reset} paw!
 
@@ -393,10 +393,10 @@ def paw(ctx: Context, flag: str, true_color: bool):
                   =@@@@@@@@@@.  .-++++-.          
                    .#@@@@@@@*                     
                      -*%@@#=                      
-    """.removeprefix("\n").removesuffix("\n")
+    """.strip("\n").rstrip()
 
-    paw_ascii = "\n".join(line.ljust(46) for line in paw_ascii.splitlines())
-    paw_ascii = "\n".join(bold + c[true_color] + l + reset for c, l in zip(_pride_colors[flag], paw_ascii.splitlines()))
+    paw_ascii = "\n".join(line.ljust(max(map(len, paw_ascii.splitlines()))) for line in paw_ascii.splitlines())
+    paw_ascii = "\n".join(bold + c[truecolor] + l + reset for c, l in zip(_pride_colors[flag], paw_ascii.splitlines()))
     echo(paw_ascii, color=ctx.color)
 
 
