@@ -302,7 +302,7 @@ def html_to_ansi(html: str, *, root: bool = False) -> str:
     for span in html_parsed.select("span.bbcode[style*=color]"):
         for child in span.select("*"):
             child.replaceWith(html_to_ansi(str(child)))
-        if (color := m[1] if (m := match(r".*color: ([^ ;]+).*", span.attrs["style"])) else "") in colors_dict:
+        if (color := m[1] if (m := match(r".*color: ([^ ;]+).*", span.attrs["style"])) else "").lower() in colors_dict:
             color = colors_dict[color]
         elif color in css_colors or color.startswith("#"):
             color = hex_to_ansi(css_colors.get(color, color), truecolor=supports_truecolor)
@@ -553,8 +553,9 @@ def database_search(ctx: Context, database: Callable[..., Database], table: str,
                                    ((*table_widths, *([0] * len(cols))) if table_widths else (10, 16, 16, 0)))]
         sort = sort or ((SubmissionsColumns.ID.name, "desc"),)
     elif table == users_table:
-        headers = headers or [*zip(cols := [UsersColumns.USERNAME.name, UsersColumns.FOLDERS.name],
-                                   ((*table_widths, *([0] * len(cols))) if table_widths else (40, 0)))]
+        headers = headers or [
+            *zip(cols := [UsersColumns.USERNAME.name, UsersColumns.ACTIVE.name, UsersColumns.FOLDERS.name],
+                 ((*table_widths, *([0] * len(cols))) if table_widths else (40, 6, 0)))]
         sort = sort or ((UsersColumns.USERNAME.name, "ASC"),)
 
     if any(h == "@" for h, _ in headers):
@@ -899,7 +900,10 @@ def database_upgrade(ctx: Context, database: Callable[..., Database]):
     """
 
     db: Database = database(check_version=False)
-    if (version := db.version) != __database_version__:
+    if (version := db.version) == __database_version__:
+        echo(f"Database is already updated to the latest version ({yellow}{__database_version__}{reset})",
+             color=ctx.color)
+    else:
         db.upgrade(check_connections=EnvVars.MULTI_CONNECTION)
         add_history(db, ctx, version_from=version, version_to=__database_version__)
 
