@@ -67,6 +67,19 @@ verbose_report_option = option("--verbose-report", is_flag=True, default=False,
 report_file_option = option("--report-file", default=None, type=File("w"), help="Write download report to a file.")
 
 
+def users_callback(ctx: Context, param: Option, value: tuple[str]) -> tuple[str]:
+    if not value or ctx.params.get("like"):
+        return value
+    value_clean: list[str] = [u if u == "@me" else clean_username(u) for u in map(str.lower, value)]
+    if invalid := [u1 for u1, u2 in zip(value, value_clean) if not u2]:
+        raise BadParameter(
+            f"User{'s' if len(invalid) - 1 else ''} {', '.join(map(repr, invalid))}"
+            f" {'do' if len(invalid) - 1 else 'does'} not contain any valid characters"
+            f" (allowed characters are [a-z0-9.~-]).",
+            ctx, param)
+    return tuple(sort_set(list(filter(bool, value_clean))))
+
+
 @group("download", cls=CustomHelpColorsGroup, short_help="Download resources.", no_args_is_help=True,
        add_help_option=False)
 @color_option
@@ -79,14 +92,6 @@ def download_app():
     pass
 
 
-def users_callback(ctx: Context, param: Option, value: tuple[str]) -> tuple[str]:
-    if not value or ctx.params.get("like"):
-        return value
-    if not (value_clean := [u.lower() if u.lower() == "@me" else clean_username(u) for u in value]):
-        raise BadParameter("No valid users (allowed characters are [a-z0-9.~-]).", ctx, param)
-    return tuple(sorted(set(value_clean), key=value_clean.index))
-
-
 @download_app.command("login", short_help="Check cookies' validity.")
 @database_exists_option
 @color_option
@@ -98,7 +103,7 @@ def download_login(ctx: Context, database: Callable[..., Database]):
     """
 
     db: Database = database()
-    api: FAAPI = open_api(db)
+    api: FAAPI = open_api(db, ctx, check_login=False)
 
     echo(f"{bold}Login{reset}", color=ctx.color)
 
@@ -137,9 +142,10 @@ def download_users(ctx: Context, database: Callable[..., Database], users: tuple
     Users are not added/deactivated.
     """
     db: Database = database()
+    api: FAAPI = open_api(db, ctx)
+    downloader: Downloader = Downloader(db, api, color=ctx.color, dry_run=dry_run)
     if not dry_run:
         add_history(db, ctx, users=users, folders=folders)
-    downloader: Downloader = Downloader(db, open_api(db), color=ctx.color, dry_run=dry_run)
     watchlist_by: list[str] = [f.split(":")[1] for f in folders if f.startswith(Folder.watchlist_by.value)]
     watchlist_to: list[str] = [f.split(":")[1] for f in folders if f.startswith(Folder.watchlist_to.value)]
     folders_ = [f for f in folders
@@ -153,6 +159,8 @@ def download_users(ctx: Context, database: Callable[..., Database], users: tuple
     folders = folders_
     try:
         downloader.download_users(list(users), list(folders))
+    except Unauthorized as err:
+        secho(f"\nError: Unauthorized{(': ' + ' '.join(err.args)) if err.args else ''}", fg="red", color=ctx.color)
     except RequestException as err:
         secho(f"\nError: An error occurred during download: {err!r}.", fg="red", color=ctx.color)
     finally:
@@ -200,11 +208,14 @@ def download_update(ctx: Context, database: Callable[..., Database], users: tupl
     Users are not added/deactivated.
     """
     db: Database = database()
+    api: FAAPI = open_api(db, ctx)
+    downloader: Downloader = Downloader(db, api, color=ctx.color, dry_run=dry_run)
     if not dry_run:
         add_history(db, ctx, users=users, folders=folders, stop=stop)
-    downloader: Downloader = Downloader(db, open_api(db), color=ctx.color, dry_run=dry_run)
     try:
         downloader.download_users_update(list(users), list(folders), stop, deactivated, like)
+    except Unauthorized as err:
+        secho(f"\nError: Unauthorized{(': ' + ' '.join(err.args)) if err.args else ''}", fg="red", color=ctx.color)
     except RequestException as err:
         secho(f"\nError: An error occurred during download: {err!r}.", fg="red", color=ctx.color)
     finally:
@@ -237,11 +248,14 @@ def download_submissions(ctx: Context, database: Callable[..., Database], submis
     The optional {yellow}--dry-run{reset} option disables downloading and saving and simply lists fetched entries
     """
     db: Database = database()
+    api: FAAPI = open_api(db, ctx)
+    downloader: Downloader = Downloader(db, api, color=ctx.color, dry_run=dry_run)
     if not dry_run:
         add_history(db, ctx, submission_id=submission_id, replace=replace)
-    downloader: Downloader = Downloader(db, open_api(db), color=ctx.color, dry_run=dry_run)
     try:
         downloader.download_submissions(list(submission_id), replace)
+    except Unauthorized as err:
+        secho(f"\nError: Unauthorized{(': ' + ' '.join(err.args)) if err.args else ''}", fg="red", color=ctx.color)
     except RequestException as err:
         secho(f"\nError: An error occurred during download: {err!r}.", fg="red", color=ctx.color)
     finally:
@@ -274,11 +288,14 @@ def download_journals(ctx: Context, database: Callable[..., Database], journal_i
     The optional {yellow}--dry-run{reset} option disables downloading and saving and simply lists fetched entries.
     """
     db: Database = database()
+    api: FAAPI = open_api(db, ctx)
+    downloader: Downloader = Downloader(db, api, color=ctx.color, dry_run=dry_run)
     if not dry_run:
         add_history(db, ctx, journal_id=journal_id, replace=replace)
-    downloader: Downloader = Downloader(db, open_api(db), color=ctx.color, dry_run=dry_run)
     try:
         downloader.download_journals(list(journal_id), replace)
+    except Unauthorized as err:
+        secho(f"\nError: Unauthorized{(': ' + ' '.join(err.args)) if err.args else ''}", fg="red", color=ctx.color)
     except RequestException as err:
         secho(f"\nError: An error occurred during download: {err!r}.", fg="red", color=ctx.color)
     finally:
