@@ -1,6 +1,9 @@
 from functools import partial
 from json import dumps
 from json import loads
+from os import R_OK
+from os import W_OK
+from os import access
 from os import environ
 from pathlib import Path
 from sys import stderr
@@ -21,7 +24,6 @@ from click.core import ParameterSource
 from click.shell_completion import CompletionItem
 from click_help_colors import HelpColorsGroup
 from faapi import FAAPI
-from faapi.exceptions import Unauthorized
 from falocalrepo_database import Database
 from requests import Response
 from requests import get
@@ -119,10 +121,23 @@ def open_database(path: Path, *, ctx: Context, param: Parameter, check_init: boo
                   check_version: bool = True, print_envvar: bool = True) -> Database:
     if print_envvar and ctx.get_parameter_source(param.name) == ParameterSource.ENVIRONMENT:
         EnvVars.print_database()
+
+    if path.is_file():
+        if not access(path, R_OK):
+            raise BadParameter(f"No read access to {str(path)!r}", ctx, param)
+        elif not access(path, W_OK):
+            raise BadParameter(f"No write access to {str(path)!r}", ctx, param)
+    elif not path.parent.is_dir():
+        raise BadParameter(f"Folder not found {str(path.parent)!r}", ctx, param)
+    elif not access(path.parent, R_OK):
+        raise BadParameter(f"No read access to folder {str(path.parent)!r}", ctx, param)
+    elif not access(path.parent, W_OK):
+        raise BadParameter(f"No write access to folder {str(path.parent)!r}", ctx, param)
+
     if EnvVars.MULTI_CONNECTION:
         if print_envvar:
             EnvVars.print_multi_connection()
-    elif path.is_file and (ps := Database.check_connection(path, raise_for_error=False)):
+    elif ps := Database.check_connection(path, raise_for_error=False):
         raise BadParameter(f"Multiple connections to database {str(path)!r}: {ps}", ctx, param)
 
     db: Database = Database(path, check_version=False, check_connections=False)
@@ -141,22 +156,31 @@ def open_database(path: Path, *, ctx: Context, param: Parameter, check_init: boo
     return db
 
 
-def open_api(db: Database) -> FAAPI:
+def open_api(db: Database, ctx: Context = None, *, check_login: bool = True) -> FAAPI:
     if not (cookies := read_cookies(db)):
-        raise Unauthorized("No cookies")
+        from .app import app
+        from .config import config_app, config_cookies
+        raise BadParameter(f"No cookies in selected database."
+                           f"\n\nSet using '{app.name} {config_app.name} {config_cookies.name}'",
+                           ctx, param_hint=repr("--database"))
 
     api: FAAPI = FAAPI(cookies)
 
     if EnvVars.CRAWL_DELAY is not None:
         EnvVars.print_crawl_delay()
-        if EnvVars.CRAWL_DELAY < (delay := int(api.robots.crawl_delay(api.user_agent) or 0)):
+        if EnvVars.CRAWL_DELAY < (delay := int(api.crawl_delay or 0)):
             raise BadParameter(f"Value lower than allowed ({delay})", param_hint=_envar_craw_delay)
-        # noinspection PyUnresolvedReferences
-        api.robots.default_entry.delay = EnvVars.CRAWL_DELAY
+        api.robots.crawl_delay = lambda *_: EnvVars.CRAWL_DELAY
     if EnvVars.FA_ROOT is not None:
         EnvVars.print_fa_root()
         faapi.connection.root = EnvVars.FA_ROOT
 
+    if check_login and not api.login_status:
+        from .app import app
+        from .config import config_app, config_cookies
+        raise BadParameter(f"Unauthorized cookies.\n\nSet using '{app.name} {config_app.name} {config_cookies.name}'",
+                           ctx)
+
     return api
 
 
