@@ -155,9 +155,11 @@ class Downloader:
         self._bar: Bar | None = None
 
         self.added_users: list[int | str] = []
+        self.added_userpages: list[int | str] = []
         self.added_submissions: list[int | str] = []
         self.added_journals: list[int | str] = []
         self.modified_users: list[int | str] = []
+        self.modified_userpages: list[int | str] = []
         self.modified_submissions: list[int | str] = []
         self.modified_journals: list[int | str] = []
         self.user_errors: list[str] = []
@@ -170,17 +172,19 @@ class Downloader:
     def report(self):
         items: list[tuple[str, int]] = [
             ("Added users", len(set(self.added_users))),
-            ("Modified users", len(self.modified_users)),
-            ("Users deactivated", len(self.user_deactivated)),
-            ("User errors", len(self.user_errors)),
+            ("Modified users", len(set(self.modified_users))),
+            ("Added userpages", len(set(self.added_userpages))),
+            ("Modified userpages", len(set(self.modified_userpages))),
+            ("Users deactivated", len(set(self.user_deactivated))),
+            ("User errors", len(set(self.user_errors))),
             ("Added submissions", len(set(self.added_submissions))),
-            ("Modified submissions", len(self.modified_submissions)),
-            ("Submission errors", len(self.submission_errors)),
-            ("File errors", len(self.file_errors)),
-            ("Thumbnail errors", len(self.thumbnail_errors)),
+            ("Modified submissions", len(set(self.modified_submissions))),
+            ("Submission errors", len(set(self.submission_errors))),
+            ("File errors", len(set(self.file_errors))),
+            ("Thumbnail errors", len(set(self.thumbnail_errors))),
             ("Added journals", len(set(self.added_journals))),
-            ("Modified journals", len(self.modified_journals)),
-            ("Journal Errors", len(self.journal_errors)),
+            ("Modified journals", len(set(self.modified_journals))),
+            ("Journal Errors", len(set(self.journal_errors))),
         ]
         if items := list(filter(itemgetter(1), items)):
             name_padding: int = max(map(len, map(itemgetter(0), items or [""])))
@@ -189,12 +193,15 @@ class Downloader:
 
     def verbose_report(self, file: TextIO | None = None):
         if file:
-            dump({"users": {
-                "added": sort_set(self.added_users),
-                "modified": sort_set(self.modified_users),
-                "errors": sort_set(self.user_errors),
-                "deactivated": sort_set(self.user_deactivated),
-            },
+            dump({
+                "users": {
+                    "added": sort_set(self.added_users),
+                    "modified": sort_set(self.modified_users),
+                    "errors": sort_set(self.user_errors),
+                    "deactivated": sort_set(self.user_deactivated),
+                    "added_userpages": sort_set(self.added_userpages),
+                    "modified_userpages": sort_set(self.modified_userpages),
+                },
                 "submissions": {
                     "added": sort_set(self.added_submissions),
                     "modified": sort_set(self.modified_submissions),
@@ -211,6 +218,8 @@ class Downloader:
             items: list[tuple[str, list[int | str]]] = [
                 ("Added users", sort_set(self.added_users)),
                 ("Modified users", sort_set(self.modified_users)),
+                ("Added userpages", sort_set(self.added_userpages)),
+                ("Modified userpages", sort_set(self.modified_userpages)),
                 ("Users deactivated", sort_set(self.user_deactivated)),
                 ("User errors", sort_set(self.user_errors)),
                 ("Added submission", sort_set(self.added_submissions)),
@@ -417,7 +426,7 @@ class Downloader:
             entry_id_getter=lambda j: j.id,
             entry_formats=("{0.id:010}", "{0.title}"),
             contains=lambda j: self.db.journals[j.id],
-            modify_checks=[(lambda journal, _: self.db.journals.set_user_update(journal.id, 1), "")],
+            modify_checks=[(lambda journal, _: self.db.journals.set_user_update(journal.id, True), "")],
             save=(lambda journal: self.db.journals.save_journal(
                 {**format_entry(dict(journal) | {"author": journal.author.name}, self.db.journals.columns),
                  JournalsColumns.USERUPDATE.value.name: 1, }), "ADDED"),
@@ -438,7 +447,7 @@ class Downloader:
             modify_checks = [(lambda submission, _: self.db.submissions.add_favorite(submission.id, user),
                               "ADDED FAV")]
         else:
-            modify_checks = [(lambda submission, _: (self.db.submissions.set_user_update(submission.id, 1) +
+            modify_checks = [(lambda submission, _: (self.db.submissions.set_user_update(submission.id, True) +
                                                      self.db.submissions.set_folder(submission.id, folder.value)),
                               "UPDATED")]
 
@@ -467,10 +476,9 @@ class Downloader:
             downloader = self.api.watchlist_to
 
         def check_folders(db: Database, watch: UserPartial, entry: dict[str, Any]) -> bool:
-            if folders_ := [f for f in folders if f not in [f_.strip("!") for f_ in entry[UsersColumns.FOLDERS.name]]]:
-                active: str = "!" if any(f.startswith("!") for f in entry[UsersColumns.FOLDERS.name]) else ""
+            if folders_ := [f for f in folders if f not in entry[UsersColumns.FOLDERS.name]]:
                 for folder in folders_:
-                    db.users.add_folder(watch.name_url, active + folder)
+                    db.users.add_folder(watch.name_url, folder)
                 return True
             return False
 
@@ -483,12 +491,14 @@ class Downloader:
             save=(lambda watch: self.db.users.save_user(
                 {UsersColumns.USERNAME.value.name: watch.name_url,
                  UsersColumns.FOLDERS.value.name: set(folders),
+                 UsersColumns.ACTIVE.value.name: True,
                  UsersColumns.USERPAGE.value.name: ""}), "ADDED"),
             stop=-1, clear_found=clear_found
         )
         self.added_users.extend(entries_added)
         self.modified_users.extend(entries_modified)
-        return 1
+
+        return err
 
     def download_user_page(self, username: str, clear_found: bool = False) -> int:
         padding: int = w - self.bar_width - 2 - 1 if (w := terminal_width()) else 0
@@ -514,8 +524,8 @@ class Downloader:
             self.clear_line()
             return 0
         self.db.users[username] = self.db.users[username] | {UsersColumns.USERPAGE.value.name: user.profile}
-        self.added_users += [username] if added else []
-        self.modified_users += [username] if updated else []
+        self.added_userpages += [username] if added else []
+        self.modified_userpages += [username] if updated else []
         self.bar_message("ADDED" if added else "UPDATED", green, always=True)
         return 0
 
@@ -542,17 +552,20 @@ class Downloader:
     def _download_users(self, users_folders: Iterable[tuple[str, list[str]]], stop: int = -1):
         operation: str = "Downloading" if stop < 0 else "Updating"
         for user, folders in users_folders:
+            user_added: bool = False
+            user_downloaded: bool = False
+            if not self.dry_run:
+                if user_added := user not in self.db.users:
+                    self.db.users.save_user({UsersColumns.USERNAME.value.name: user,
+                                             UsersColumns.FOLDERS.value.name: {},
+                                             UsersColumns.ACTIVE.value.name: True,
+                                             UsersColumns.USERPAGE.value.name: ""})
+                    self.db.commit()
+                    self.added_users += [user]
+                self.db.users.set_active(user, True)
             for folder in folders:
                 echo(f"{operation}: {yellow}{user}{reset}/{yellow}{folder.split(':')[0]}{reset}", color=self.color)
-                user_added: bool = False
                 if not self.dry_run:
-                    if user_added := user not in self.db.users:
-                        self.db.users.save_user({UsersColumns.USERNAME.value.name: user,
-                                                 UsersColumns.FOLDERS.value.name: {},
-                                                 UsersColumns.USERPAGE.value.name: ""})
-                        self.db.commit()
-                        self.added_users += [user]
-                    self.db.users.activate(user)
                     if folder.startswith(w := Folder.watchlist_by) and \
                             (wfs := [f for f in self.db.users[user][UsersColumns.FOLDERS.name] if f.startswith(w)]):
                         for wf in filter(lambda f: f != folder, wfs):
@@ -563,7 +576,8 @@ class Downloader:
                         for wf in filter(lambda f: f != folder, wfs):
                             self.db.users.remove_folder(user, wf)
                         self.modified_users += [user]
-                    self.db.users.add_folder(user, folder)
+                    added_folder: bool = self.db.users.add_folder(user, folder)
+                    self.modified_users += [user] if not user_added and added_folder else []
                 err: int
                 if folder == Folder.userpage:
                     err = self.download_user_page(user, stop == 1)
@@ -577,14 +591,14 @@ class Downloader:
                     err = self.download_user_watchlist(user, Folder.watchlist_to, folder.split(":")[1:], stop == 1)
                 else:
                     raise Exception(f"Unknown folder {folder}")
-                if err in (1, 2):
-                    if self.dry_run:
-                        pass
-                    elif user_added:
+                if not err:
+                    user_downloaded = True
+                elif not self.dry_run and err in (1, 2):
+                    if user_added and not user_downloaded:
                         del self.db.users[user]
                         self.added_users.remove(user)
-                    elif err == 2:
-                        self.db.users.deactivate(user)
+                    else:
+                        self.db.users.set_active(user, False)
                         self.user_deactivated += [user]
                     self.db.commit()
                     break
@@ -622,24 +636,22 @@ class Downloader:
             users_cursor = self.db.users[users]
         else:
             users_cursor = self.db.users.select(order=[UsersColumns.USERNAME.value.name])
-        users_folders: Iterable[tuple[str, list[str]]]
-        users_folders = ((u[UsersColumns.USERNAME.value.name], [f for f in u[UsersColumns.FOLDERS.value.name]])
-                         for u in users_cursor)
+        users_folders: list[tuple[str, list[str]]]
+        users_folders = [(u[UsersColumns.USERNAME.value.name], [*u[UsersColumns.FOLDERS.value.name]])
+                         for u in users_cursor if u[UsersColumns.ACTIVE.value.name] or deactivated]
 
         users_folders = sorted(users_folders, key=lambda uf: users.index(uf[0]) if users and not like else uf[0])
 
-        if deactivated:
-            users_folders = ((u, [*map(lambda f: f.strip("!"), fs)]) for u, fs in users_folders)
-        else:
-            users_folders = ((u, fs) for u, fs in users_folders if not any("!" in f for f in fs))
-
         if folders:
-            users_folders = ((u, sorted(filter(lambda f: f.split(":")[0] in folders, fs),
+            users_folders = [(u, sorted(filter(lambda f: f.split(":")[0] in folders, fs),
                                         key=lambda f: folders.index(f.split(":")[0])))
-                             for u, fs in users_folders)
+                             for u, fs in users_folders]
         else:
-            users_folders = ((u, sorted(fs, key=lambda f: Folder.as_list().index(f.split(":")[0])))
-                             for u, fs in users_folders)
+            users_folders = [(u, sorted(fs, key=lambda f: Folder.as_list().index(f.split(":")[0])))
+                             for u, fs in users_folders]
+
+        if not users_folders:
+            return echo("No users to update")
 
         self._download_users(users_folders, stop)
 
